@@ -1,5 +1,5 @@
 /*  QuickSynergy -- a GUI for synergy
- *  Copyright (C) 2006, 2007 Cesar L. B. Silveira, Otavio C. Cordeiro
+ *  Copyright (C) 2006, 2007, 2008 Cesar L. B. Silveira, Otavio C. Cordeiro
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,9 +30,6 @@
 #include "synergy_config.h"
 #include "intl.h"
 
-#define SYNERGY_SERVER_RUNNING 1
-#define SYNERGY_CLIENT_RUNNING 2
-
 #ifdef HAVE_GTK_2_10
 static GtkUIManager *ui_manager = NULL;
 static GtkActionGroup *action_group;
@@ -52,15 +49,14 @@ static GtkActionEntry popup_menu_actions[] = {
 };
 #endif
 
+pid_t pid;
+
 extern GtkWidget *main_window;
 extern GtkWidget *notebook;
 extern GtkWidget *hostname_entry;
 extern GtkWidget *table;
 extern GtkWidget *vbox0;
 extern int synergy_running;
-#ifndef HAVE_GTK_2_10
-extern int keep_running;
-#endif
 extern const guint8 qslogo[];
 
 gboolean entry_focus_in_event(
@@ -91,41 +87,45 @@ gboolean entry_focus_out_event(
     return FALSE;
 }
 
-#ifndef HAVE_GTK_2_10
-void keep_running_toggled(GtkToggleButton *button, gpointer user_data) {
-    if(gtk_toggle_button_get_active(button) == TRUE) {
-        keep_running = 1;
-    }
-    else {
-        keep_running = 0;
-    }
-}
-#endif
-
 void about_button_clicked(GtkWidget *widget, gpointer data) {
-    GtkWidget *about;
-    gchar *authors[2] = { "César L. B. Silveira", NULL };
-    gchar *documenters[3] = { "Otávio C. Cordeiro", "César L. B. Silveira", NULL };
+    GtkWidget *window = (GtkWidget *) data;
+    
+    static const gchar *authors[] = {
+        "César L. B. Silveira <cesarbs@gmail.com>",
+        "Otávio C. Cordeiro <otavio@gmail.com>",
+        "Jérémie Corbier (patches and Debian and Ubuntu packaging)",
+        "Thomas Langewouters (patches and suggestions)",
+        "Magnus Boman (patches)",
+        "Todd Wease (patches)",
+        NULL
+    };
+    
+    static const gchar *documenters[] = {
+        "César L. B. Silveira <cesarbs@gmail.com>",
+        "Otávio C. Cordeiro <otavio@gmail.com>",
+        NULL
+    };
+    
+    static const gchar *copyright =
+        "Copyright \xc2\xa9 2006-2008 César L. B. Silveira, Otávio C. Cordeiro";
+    
+    GdkPixbuf *logo = gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL);
 
-    /* build and display the about dialog */
-    about = gtk_about_dialog_new();
-    gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about), "quicksynergy");
-    gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about), VERSION);
-    gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about), 
-            gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL));
-    gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about),
-            _("A GUI for synergy"));
-    gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(about), 
-            "http://quicksynergy.sourceforge.net");
-    gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about), 
-            (const gchar **) authors);
-    gtk_about_dialog_set_documenters(GTK_ABOUT_DIALOG(about), 
-            (const gchar **) documenters);
-    gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG(about),
-            _("translator-credits"));
+    gtk_show_about_dialog(GTK_WINDOW(window),
+                    "comments", _("A graphical user interface for synergy"),
+                    "authors", authors,
+                    "documenters", documenters,
+                    "copyright", copyright,
+                    "logo", logo,
+                    "translator-credits", _("translator-credits"),
+                    "version", VERSION,
+                    "website", "http://quicksynergy.sourceforge.net",
+                    "name", "QuickSynergy",
+                    NULL);
 
-    gtk_dialog_run(GTK_DIALOG(about));
-    gtk_widget_destroy(about);
+    if(logo) {
+        g_object_unref(logo);
+    }
 }
 
 void start_button_clicked(GtkWidget *widget, gpointer data) {
@@ -144,24 +144,9 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
         
             sprintf(filename, "%s%s", env_home, "/.quicksynergy/synergy.conf");
             
-#ifdef  HAVE_GTK_2_10
-            if((fork()) == 0) {
+            if((pid = fork()) == 0) {
                 execlp("synergys", "synergys", "-f", "--config",  filename, NULL);
             }
-#else
-            if((fork()) == 0) {
-                if(keep_running) {
-                    execlp("synergys", "synergys", "--config",  filename, NULL);
-                }
-                else {
-                    execlp("synergys", "synergys", "-f", "--config",  filename, NULL);
-                }
-            }
-            else {
-                if(keep_running)
-                    wait(&status);
-            }
-#endif
             
             gtk_widget_set_sensitive(notebook, FALSE);
             
@@ -170,26 +155,13 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
             synergy_running = SYNERGY_SERVER_RUNNING;
         }
         else if(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)) == 1) {
+            save_config();
+
             hostname = 
                 (char *) gtk_entry_get_text(GTK_ENTRY(hostname_entry));
-#ifdef HAVE_GTK_2_10
-            if((fork()) == 0) {
+            if((pid = fork()) == 0) {
                 execlp("synergyc", "synergyc", "-f", hostname, NULL);
             }
-#else
-            if((fork()) == 0) {
-                if(keep_running) {
-                    execlp("synergyc", "synergyc", hostname, NULL);
-                }
-                else {
-                    execlp("synergyc", "synergyc", "-f", hostname, NULL);
-                }
-            }
-            else {
-                if(keep_running)
-                    wait(&status);
-            }
-#endif
 
             synergy_running = SYNERGY_CLIENT_RUNNING;
         }
@@ -198,16 +170,9 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
         gtk_widget_set_sensitive(notebook, FALSE);
     }
     else {
-        /* kill all synergy processes */
-        system("killall synergys");
-        system("killall synergyc");
+        kill(pid, SIGTERM);
 
-#ifdef HAVE_GTK_2_10
         wait(&status);
-#else
-        if(!keep_running)
-            wait(&status);
-#endif
         
         gtk_button_set_label(GTK_BUTTON(widget), GTK_STOCK_EXECUTE);
         gtk_widget_set_sensitive(notebook, TRUE);
@@ -219,9 +184,7 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
 #ifdef HAVE_GTK_2_10
 void quicksynergy_quit(GtkWidget *widget, gpointer data) {
     if(synergy_running) {
-        /* kill all synergy processes */
-        system("killall synergys");
-        system("killall synergyc");
+        kill(pid, SIGTERM);
     }
     
     save_config();
@@ -238,10 +201,8 @@ gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
 }
 #else
 void close_button_clicked(GtkWidget *widget, gpointer data) {   
-    if(synergy_running && !keep_running) {
-        /* kill all synergy processes */
-        system("killall synergys");
-        system("killall synergyc");
+    if(synergy_running) {
+        kill(pid, SIGTERM);
     }
     
     save_config();
@@ -252,14 +213,8 @@ void close_button_clicked(GtkWidget *widget, gpointer data) {
 gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
     int status;
     
-    if(synergy_running && !keep_running) {
-        if(fork() == 0) {
-            execlp("killall", "killall", "synergys", NULL);
-            execlp("killall", "killall", "synergyc", NULL);
-        }
-        else {
-            wait(&status);
-        }
+    if(synergy_running) {
+        kill(pid, SIGTERM);
     }
     
     save_config();
