@@ -1,5 +1,5 @@
 /*  QuickSynergy -- a GUI for synergy
- *  Copyright (C) 2006, 2007 Cesar L. B. Silveira, Otavio C. Cordeiro
+ *  Copyright (C) 2006, 2007, 2008 Cesar L. B. Silveira, Otavio C. Cordeiro
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,20 +24,32 @@
 #include "logo/qslogo.h"
 #include "callbacks.h"
 #include "synergy_config.h"
-#include "screen_entry.h"
-#include "proc.h"
 #include "intl.h"
 
 GtkWidget *main_window;
 GtkWidget *notebook;
-GtkWidget *hostname_entry;
 GtkWidget *table;
 GtkWidget *vbox0;
-GtkWidget *above_entry, *below_entry, *left_entry, *right_entry;
+GtkWidget *above_entry, *below_entry, *left_entry, *right_entry, *hostname_entry;
 int synergy_running = 0;
-#ifndef HAVE_GTK_2_10
-int keep_running;
-#endif
+
+static GtkWidget *screen_entry_new(const char *position) {
+    GtkWidget *entry;
+
+    entry = gtk_entry_new();
+
+    gtk_entry_set_text(GTK_ENTRY(entry), position);
+    gtk_entry_set_alignment(GTK_ENTRY(entry), 0.5);
+    gtk_entry_set_width_chars(GTK_ENTRY(entry), 10);
+
+    g_signal_connect(G_OBJECT(entry), "focus-in-event",
+    G_CALLBACK(entry_focus_in_event), (gpointer) position);
+
+    g_signal_connect(G_OBJECT(entry), "focus-out-event",
+    G_CALLBACK(entry_focus_out_event), (gpointer) position);
+
+    return entry;
+}
 
 int main(int argc, char **argv) {
     GtkWidget *vbox;
@@ -72,6 +84,8 @@ int main(int argc, char **argv) {
             GTK_WIN_POS_CENTER);
     gtk_window_set_resizable(GTK_WINDOW(main_window), FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(main_window), 5);
+    gtk_window_set_icon(main_window,gdk_pixbuf_new_from_inline(-1, qslogo,
+        FALSE, NULL));
     
     /* main window events */
     g_signal_connect(G_OBJECT(main_window), "delete_event",
@@ -103,19 +117,10 @@ int main(int argc, char **argv) {
     gtk_table_attach_defaults(GTK_TABLE(table), right_entry, 2, 3, 1, 2);       
     
     /* image to be displayed in the center of the main window */
-    //image = gtk_image_new_from_pixbuf(
-    //  gdk_pixbuf_new_from_xpm_data((const char **) logo_data));
     image = gtk_image_new_from_pixbuf(
         gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL));
     gtk_table_attach_defaults(GTK_TABLE(table), image, 1, 2, 1, 2);
     
-    /*
-    gtk_table_set_row_spacings(GTK_TABLE(table), 30);
-    gtk_table_set_col_spacings(GTK_TABLE(table), 5);    
-    label = gtk_label_new("laodicea");
-    gtk_table_attach_defaults(GTK_TABLE(table), label, 1, 2, 1, 2);
-    */
-    
     /* add server page to the notebook */
     page_label = gtk_label_new(_("Share"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, page_label);
@@ -136,23 +141,6 @@ int main(int argc, char **argv) {
     page_label = gtk_label_new(_("Use"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox0, page_label);
 
-#ifndef HAVE_GTK_2_10   
-    /* settings page */
-    vbox0 = gtk_vbox_new(FALSE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(vbox0), 5);
-    
-    /* check button for setting the KeepRunning option */
-    check_button = gtk_check_button_new_with_label(
-        _("Keep synergy running after QuickSynergy is closed"));
-    g_signal_connect(G_OBJECT(check_button), "toggled",
-        G_CALLBACK(keep_running_toggled), NULL);
-    gtk_box_pack_start(GTK_BOX(vbox0), check_button, FALSE, FALSE, 0);
-    
-    /* add settings page to notebook */
-    page_label = gtk_label_new(_("Settings"));
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox0, page_label);
-#endif
-    
     /* pack the notebook into the main vbox */
     gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
     
@@ -167,7 +155,7 @@ int main(int argc, char **argv) {
     about_button = gtk_button_new_with_label(GTK_STOCK_ABOUT);
     gtk_button_set_use_stock(GTK_BUTTON(about_button), TRUE);
     g_signal_connect(G_OBJECT(about_button), "clicked",
-        G_CALLBACK(about_button_clicked), NULL);
+        G_CALLBACK(about_button_clicked), main_window);
     gtk_box_pack_start(GTK_BOX(hbox), about_button, TRUE, TRUE, 0);
     
     /* start/stop button */
@@ -190,27 +178,6 @@ int main(int argc, char **argv) {
     /* load previous configuration */
     load_config();
 
-#ifndef HAVE_GTK_2_10   
-    /* if the KeepRunning configuration option is 1, set the
-     * settings check button to an active state */
-    if(keep_running) {
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), TRUE);
-    }
-#endif
-    
-    /* check if synergy is already running */
-    if((pid = get_pid_by_name("synergys"))) {
-        gtk_button_set_label(GTK_BUTTON(start_button), _("Stop"));
-        gtk_widget_set_sensitive(notebook, FALSE);
-        synergy_running = 1;
-    }
-    else if((pid = get_pid_by_name("synergyc"))) {
-        gtk_button_set_label(GTK_BUTTON(start_button), _("Stop"));
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
-        gtk_widget_set_sensitive(notebook, FALSE);
-        synergy_running = 1;
-    }
-    
 #ifdef HAVE_GTK_2_10
     status_icon = gtk_status_icon_new_from_pixbuf(
         gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL));
@@ -220,6 +187,9 @@ int main(int argc, char **argv) {
     
     g_signal_connect(G_OBJECT(status_icon), "popup-menu", 
         G_CALLBACK(status_icon_popup), NULL);
+    
+    g_signal_connect(G_OBJECT(status_icon), "activate", 
+        G_CALLBACK(show_main_window), NULL);
 #endif
 
     /* display the main window */   
