@@ -1,5 +1,5 @@
 /*  QuickSynergy -- a GUI for synergy
- *  Copyright (C) 2006, 2007 Cesar L. B. Silveira, Otavio C. Cordeiro
+ *  Copyright (C) 2006, 2007, 2008 Cesar L. B. Silveira, Otavio C. Cordeiro
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,10 +26,7 @@
 #include "synergy_config.h"
 #include "intl.h"
 
-extern GtkWidget *above_entry, *below_entry, *left_entry, *right_entry;
-#ifndef HAVE_GTK_2_10
-extern int keep_running;
-#endif
+extern GtkWidget *above_entry, *below_entry, *left_entry, *right_entry, *hostname_entry;
 
 void load_config() {
     const char *env_home = getenv("HOME");
@@ -57,10 +54,9 @@ void load_config() {
                 else if(!strcmp(option, "Right"))
                     gtk_entry_set_text(
                             GTK_ENTRY(right_entry), value);
-#ifndef HAVE_GTK_2_10
-                else if(!strcmp(option, "KeepRunning"))
-                    keep_running = atoi(value);
-#endif
+                else if(!strcmp(option, "Host"))
+                    gtk_entry_set_text(
+                            GTK_ENTRY(hostname_entry), value);
             }
         } while(!feof(f));
     }
@@ -104,9 +100,7 @@ void save_config() {
        strcmp(gtk_entry_get_text(GTK_ENTRY(right_entry)), ""))
         fprintf(f, "Right %s\n", gtk_entry_get_text(GTK_ENTRY(right_entry)));
 
-#ifndef HAVE_GTK_2_10
-    fprintf(f, "KeepRunning %d\n", keep_running);
-#endif
+    fprintf(f, "Host %s\n", gtk_entry_get_text(GTK_ENTRY(hostname_entry)));
     
     fclose(f);
 }
